==> hibernate-search-mapper-pojo-standalone-8.0.0.Final.jar: module-info.java <==
/* synthetic */ module org.hibernate.search.mapper.pojo.standalone {
    /* transitive */ requires org.hibernate.search.engine;
    /* transitive */ requires org.hibernate.search.mapper.pojo;
    /* transitive */ requires org.hibernate.search.util.common;
    requires org.jboss.jandex;
    requires org.jboss.logging;

    exports org.hibernate.search.mapper.pojo.standalone.bootstrap.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.standalone.bootstrap.spi;
    exports org.hibernate.search.mapper.pojo.standalone.cfg;
    exports org.hibernate.search.mapper.pojo.standalone.cfg.spi;
    exports org.hibernate.search.mapper.pojo.standalone.entity;
    exports org.hibernate.search.mapper.pojo.standalone.loading;
    exports org.hibernate.search.mapper.pojo.standalone.loading.binding;
    exports org.hibernate.search.mapper.pojo.standalone.loading.dsl;
    exports org.hibernate.search.mapper.pojo.standalone.loading.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.standalone.logging.impl to org.jboss.logging, org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.standalone.mapping;
    exports org.hibernate.search.mapper.pojo.standalone.mapping.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.standalone.mapping.metadata;
    exports org.hibernate.search.mapper.pojo.standalone.massindexing;
    exports org.hibernate.search.mapper.pojo.standalone.massindexing.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.standalone.model.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.standalone.reporting.impl to org.jboss.logging, org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.standalone.schema.management;
    exports org.hibernate.search.mapper.pojo.standalone.schema.management.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.standalone.scope;
    exports org.hibernate.search.mapper.pojo.standalone.scope.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.standalone.session;
    exports org.hibernate.search.mapper.pojo.standalone.session.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.standalone.tenancy.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.standalone.work;
    exports org.hibernate.search.mapper.pojo.standalone.work.impl to org.hibernate.search.engine;

}

==> hibernate-search-mapper-pojo-standalone-8.1.1.Final.jar: module-info.java <==
/* synthetic */ module org.hibernate.search.mapper.pojo.standalone {
    /* transitive */ requires org.hibernate.search.engine;
    /* transitive */ requires org.hibernate.search.mapper.pojo;
    /* transitive */ requires org.hibernate.search.util.common;
    requires org.jboss.jandex;
    requires org.jboss.logging;

    exports org.hibernate.search.mapper.pojo.standalone.bootstrap.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.standalone.bootstrap.spi;
    exports org.hibernate.search.mapper.pojo.standalone.cfg;
    exports org.hibernate.search.mapper.pojo.standalone.cfg.spi;
    exports org.hibernate.search.mapper.pojo.standalone.entity;
    exports org.hibernate.search.mapper.pojo.standalone.loading;
    exports org.hibernate.search.mapper.pojo.standalone.loading.binding;
    exports org.hibernate.search.mapper.pojo.standalone.loading.dsl;
    exports org.hibernate.search.mapper.pojo.standalone.loading.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.standalone.logging.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.standalone.mapping;
    exports org.hibernate.search.mapper.pojo.standalone.mapping.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.standalone.mapping.metadata;
    exports org.hibernate.search.mapper.pojo.standalone.massindexing;
    exports org.hibernate.search.mapper.pojo.standalone.massindexing.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.standalone.model.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.standalone.reporting.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.standalone.schema.management;
    exports org.hibernate.search.mapper.pojo.standalone.schema.management.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.standalone.scope;
    exports org.hibernate.search.mapper.pojo.standalone.scope.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.standalone.session;
    exports org.hibernate.search.mapper.pojo.standalone.session.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.standalone.tenancy.impl to org.hibernate.search.engine;
    exports org.hibernate.search.mapper.pojo.standalone.work;
    exports org.hibernate.search.mapper.pojo.standalone.work.impl to org.hibernate.search.engine;

}
